/*
 * Copyright 2009 Olivier Godineau
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package olg.csv.base;

import java.io.Closeable;

/**
 * Writer Interface.
 * 
 * @author Olivier Godineau
 * 
 */
public interface IWriter extends Closeable {

	/**
	 * Adds a row.
	 * 
	 * <p>
	 * The first row allows to define the size used along writing unless
	 * {@link #addLine(String[])} had been used first.
	 * </p>
	 * <p>
	 * Throws a WriterException when row size differs from initial size or row
	 * num is lesser than the expected next number line. Or if I/O error occurs
	 * during writing.
	 * </p>
	 * 
	 * @param row
	 *            the row. It's possible to use a row with no cells. In this
	 *            case, an empty line(a line wich all fields are null) is added.
	 *            It's possible to use a row with a num greater than the
	 *            expected number. In this case, empty lines are wroten as much
	 *            as necessary. It's possible to use row which all cells are not
	 *            specified. In this case the missing cells are added as empty
	 *            cells. Must be not null with cells correctly ordered and
	 *            size>0.
	 */
	void addRow(Row row);

	/**
	 * Adds a row from the given String array. The first time this method define
	 * the size ( as the given string array length) used along writing unless
	 * {@link #addRow(Row)} had been used first.
	 * <p>
	 * Throws a WriterException when line size differs from initial size.
	 * </p>
	 * 
	 * @param values
	 *            the row. Must be not <code>null</code> with length >0. .
	 * 
	 */
	void addLine(String[] values);

	/**
	 * Indicates if the file has a headers line.
	 * 
	 * @return true if the file has a headers line.
	 */
	boolean isWithHeaders();
}
