/*
 * Copyright 2012 Olivier Godineau
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package olg.csv.bean;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;

/**
 * Provides main method to extraxt XSD schema from jar.
 * 
 * @author Olivier Godineau
 * 
 */
public final class SchemaMain {

	/**
	 * Namespace to use within your XML Declaration.
	 */
	public static final String BASE_NAMESPACE_MAPPING = "http://www.example.org/row-bean";

	/**
	 * private constructor to prevent its instantiation.
	 */
	private SchemaMain() {

	}

	/**
	 * Allows to write in a file named bean-row.xsd the xsd schema used to
	 * create reader or writer configuration.
	 * 
	 * @param args
	 *            unused
	 */
	public static void main(String[] args) {
		System.out.println("Copy of bean-row.xsd ..."); // NOPMD by olivier on
														// 05/01/12 01:02

		File destination = new File("bean-row.xsd");

		InputStream input = null;
		java.io.FileOutputStream destinationFile = null;
		try {

			input = Util.class.getResourceAsStream("bean-row.xsd");
			destinationFile = new FileOutputStream(destination);

			byte[] buffer = new byte[512 * 1024];
			int nbLecture;

			while ((nbLecture = input.read(buffer)) != -1) { // NOPMD by olivier
																// on 28/01/12
																// 14:17
				destinationFile.write(buffer, 0, nbLecture);
			}

			System.out.println("Done"); // NOPMD by olivier on 05/01/12 01:02
			System.out.println("See your copy " + destination.getAbsolutePath()); // NOPMD
																					// by
																					// olivier
																					// on
																					// 05/01/12
																					// 01:02
			System.out.println("Don't forget to declare the following namespace in your XML Declaration :"
					+ BASE_NAMESPACE_MAPPING); // NOPMD by olivier on 05/01/12
												// 01:02
		} catch (FileNotFoundException e) {

			e.printStackTrace(); // NOPMD by olivier on 05/01/12 01:03
		} catch (IOException e) {

			e.printStackTrace(); // NOPMD by olivier on 05/01/12 01:03
		} finally {
			if (destinationFile != null) {
				try {
					destinationFile.close();
				} catch (IOException ex) {
					ex.printStackTrace(); // NOPMD by olivier on 28/01/12 14:13
				}
			}

			if (input != null) {
				try {
					input.close();
				} catch (IOException ex) {
					ex.printStackTrace(); // NOPMD by olivier on 28/01/12 14:13
				}
			}

		}

	}
}
