/*
 * Copyright 2013 Olivier Godineau
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package olg.csv.bean.annotations;

/**
 * Provides @Param names for ODSReading / ODSWriting setted on @RowBean.
 * 
 * @author Olivier Godineau
 * @see olg.csv.base.ods.ODSSettings
 */
public final class ODSProperty {
	/**
	 * Provides static method only.
	 */
	private ODSProperty() {

	}
	/**
	 * Name of a property for ODS reader/writer. This property allows to define
	 * the withHeaders param. Default is
	 * {@link olg.csv.base.AbstractSheetSettings#DEFAULT_WITHHEADERS}
	 */
	public static final String HEADERS = "headers";

	/**
	 * Name of a property for ODS reader. This property allows to define the num
	 * of the sheet to be read. Default is
	 * {@link olg.csv.base.AbstractSheetSettings#DEFAULT_SHEETNUM}
	 */
	public static final String SHEETNUM = "sheetNum";
	/**
	 * Name of a property for ODS reader/writer. This property allows to define
	 * the name of the sheet to be read or written. If defined sheetnum will be
	 * ignored.
	 */
	public static final String SHEETNAME = "sheetName";
	/**
	 * Name of a property for ODS reader/writer. This property allows to specify
	 * which line of the file, starts the reading or writing.
	 * 
	 */

	public static final String BEGIN_AT_ROW = "beginAtRow";

	/**
	 * Name of a property for ODS reader. This property allows to specify which
	 * line of the file ends the reading. If <code>null</code>, end at the last
	 * line. Only on reading process
	 * 
	 */
	public static final String END_AT_ROW = "endAtRow";

	/**
	 * Name of a property for ODS reader/writer. This property allows to specify
	 * which column of each line starts the reading or writing. Sheet cell
	 * number format('A', 'B', 'C',..., 'AA', ...) or integer Format.
	 */
	public static final String BEGIN_AT_COLUMN = "beginAtColumn";

	/**
	 * Name of a property for ODS reader. This property allows to specify which
	 * column of each line end reading. Sheet cell number format('A', 'B',
	 * 'C',..., 'AA', ...) or integer Format.
	 */
	public static final String END_AT_COLUMN = "endAtColumn";

}
