/*
 * Copyright 2012 Olivier Godineau
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package olg.csv.bean.formatter;

import java.util.Arrays;

/**
 * Converts array of T into String.
 * 
 * @param <T>
 *            The formatter deals array of T class.
 */
public final class ArrayFormatter<T> extends Formatter<T[]> {

	/**
	 * Formatter responsible of formatting T object.
	 */
	private final Formatter<T> formatter;

	@Override
	public String toString(T[] array) {

		String[] results = new String[array.length];
		int index = 0;
		for (T valeur : array) {
			String value = formatter.toString(valeur);
			if (value.indexOf(',') != -1 || value.indexOf('\"') != -1) {
				value = new StringBuilder("\"").append(value.replaceAll("\"", "\"\"")).append("\"").toString();
			}
			results[index++] = value;
		}
		return Arrays.toString(results);
	}

	/**
	 * Constructs an instance with a formatter.
	 * 
	 * @param formatter
	 *            formatter responsible of T converting
	 */
	private ArrayFormatter(Formatter<T> formatter) {
		super();
		this.formatter = formatter;
	}

	/**
	 * Constructs an instance with default formatter.
	 */
	private ArrayFormatter() {
		super();
		this.formatter = new Formatter<T>();
	}
}