/*
 * Copyright 2012 Olivier Godineau
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package olg.csv.bean.formatter;

import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.Locale;

/**
 * Class dedicated in Date formatting.
 * 
 */
public final class DateFormatter extends Formatter<Date> {
	/**
	 * The date format.
	 */
	private final DateFormat dateFormat;
	// TODO s'assurer que le dateformatter convient dans le cas de classe enfant
	// à java.util.Date!!
	@Override
	public String toString(Date date) {

		return dateFormat.format(date);
	}

	/**
	 * Constructs a date formatter with the given pattern and default locale.
	 * 
	 * @param pattern
	 *            the date pattern. must not be <code>null</code>.
	 */
	public DateFormatter(String pattern) {
		super();
		dateFormat = new SimpleDateFormat(pattern);
	}

	/**
	 * 
	 * @param pattern
	 *            the date pattern. Must not be <code>null</code>.
	 * @param locale
	 *            the locale. Must not be <code>null</code>.
	 */
	public DateFormatter(String pattern, Locale locale) {
		super();
		dateFormat = new SimpleDateFormat(pattern, locale);
	}

}