/*
 * Copyright 2012 Olivier Godineau
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package olg.csv.bean.getter.impl;

import olg.csv.base.Cell;
import olg.csv.base.Row;
import olg.csv.bean.getter.AbstractGetter;
import olg.csv.bean.getter.GetterException;

/**
 * Default getter based on extract cell from a row.
 * 
 */
public final class DefaultGetter extends AbstractGetter {

	/**
	 * the cell num.
	 */
	private int rang;

	/**
	 * Returns the rank of the target cell.
	 * 
	 * @return the number of the cell
	 */
	public int getRang() {
		return rang;
	}

	/**
	 * Sets the rank of the target cell.
	 * 
	 * @param rang
	 *            the cell num. Must not be greater or equals 0.
	 */
	public void setRang(int rang) {
		if (rang < 0) {
			throw new IllegalArgumentException("Rang only greater or equals  0");
		}
		this.rang = rang;
	}

	/**
	 * Extracts the target cell value from the given row.
	 * 
	 * @param line
	 *            the row from which get the string.
	 * @return the string.
	 */
	@Override
	protected String doGet(Row line) {
		String retour = null;
		if (line != null) {
			if (line.getSize() > rang) {
				Cell cell = line.getCell(rang);
				retour = (cell == null ? null : cell.getValue());
			} else {
				throw new GetterException(String.format("rang[%s] too high in the row %s", rang, line));
			}
		}
		return retour;
	}

	/**
	 * Constructor with cell rank in argument.
	 * 
	 * @param rang
	 *            a non negative integer or a string in Sheet cell number format
	 *            (as C, AB ,... )
	 */
	public DefaultGetter(String rang) {
		super();
		this.rang = Cell.fromSheetCellNumber(rang);

	}
}