package olg.csv.bean.annotations.sample;

import java.io.File;
import java.io.IOException;
import java.io.PrintStream;

import olg.csv.base.IWriter;
import olg.csv.base.WriterException;
import olg.csv.base.csv.CSVSettings;
import olg.csv.base.csv.CSVWriter;
import olg.csv.bean.BeanWriter;
import olg.csv.bean.IRowProcessor;
import olg.csv.bean.PropertyException;
import olg.csv.bean.annotations.processor.AnnotationProcessorException;
import olg.csv.bean.annotations.processor.RowBeanProcessor;
import olg.csv.bean.sample.model.ModelSample;
import olg.csv.bean.sample.model.Person;

public class ExportPersonCustom {

	private static String OUT_FILE = "ExportedPersonCustom.csv";
	/**
	 * Try to write some persons into a CSV file. <li>export persons into csv
	 * file by using of writedCfg.xml configuration(bean-writer configuration,
	 * only for writing exposed in resources package )</li> </ul>
	 * 
	 * @param args
	 *            an output directory path may be specified where to create file
	 */
	public static void main(String[] args) {
		PrintStream out = System.out;
		String directory = null;
		if (args.length > 0) {
			directory = args[0];
		}

		File outFile = new File(directory, OUT_FILE);

		out.println("CSV EXPORT ");
		out.println("Out file :" + outFile.getAbsolutePath());

		// Annotation processor
		RowBeanProcessor<Person> rowBean = new RowBeanProcessor<Person>(Person.class);
		// Row Processor (productrows from persons)
		IRowProcessor<Person> rowProcessor = null;
		// the writer (write rows in the out file)
		IWriter writer = null;

		// the person writer (directly write person on the out file)
		BeanWriter<Person> personWriter = null;

		// The really stuff begins now
		try {
			// The row processor read from annotation setted on Person.
			rowProcessor = rowBean.getRowProcessor();

			// you could retreive CSVSettings from RowBean annotation in the aim
			// of customizing : CSVSettings settings =
			// rowBean.getWritingCSVSettings();
			// Or build it :
			CSVSettings settings = new CSVSettings().setCharsetName("UTF-8").setDelimiter('\'').setSeparator(',')
					.setWithHeaders(true);

			// The writer
			writer = new CSVWriter(outFile, settings);

			personWriter = new BeanWriter<Person>(rowProcessor, writer);

			Person person = ModelSample.getHolmes();
			try {
				personWriter.write(person);
			} catch (PropertyException ex) {
				out.println("Something went wrong with " + person);
				ex.printStackTrace();
			}

			person = ModelSample.getLupin();
			try {
				personWriter.write(person);
			} catch (PropertyException ex) {
				out.println("Something went wrong with " + person);
				ex.printStackTrace();
			}

			person = ModelSample.getPoirot();
			try {
				personWriter.write(person);
			} catch (PropertyException ex) {
				out.println("Something went wrong with " + person);
				ex.printStackTrace();
			}

			out.println("See " + outFile.getAbsolutePath());
		} catch (IOException e) {
			e.printStackTrace();
		} catch (AnnotationProcessorException e) {

			e.printStackTrace();
		} catch (WriterException e) {
			e.printStackTrace();
		}

	}
}
