/*
 * Copyright 2014 Olivier Godineau
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package olg.csv.bean.annotations.sample;

import java.io.File;
import java.io.IOException;

import olg.csv.base.IReader;
import olg.csv.base.csv.CSVReader;
import olg.csv.base.csv.CSVSettings;
import olg.csv.bean.BeanReader;
import olg.csv.bean.IBeanProcessor;
import olg.csv.bean.annotations.processor.AnnotationProcessorException;
import olg.csv.bean.annotations.processor.RowBeanProcessor;
import olg.csv.bean.parser.ParseException;
import olg.csv.bean.sample.model.Person;

/**
 * Sample CSV Reading when the CSVReader doesn't use default settings read from
 * RowBeanAnnotation or when RowBean.fromFile is not appropriate(when the
 * returned list is too big).
 * 
 * @author Olivier Godineau
 * 
 */
public class ImportPersonCustom {
	public final static File IN_FILE = new File(ImportPerson.class.getResource("ImportPersonCustom.csv").getFile());
	public static void main(String[] args) {

		// Annotation processor
		RowBeanProcessor<Person> rowBean = new RowBeanProcessor<Person>(Person.class);
		IBeanProcessor<Person> beanProcessor = null;
		IReader reader = null;
		BeanReader<Person> personReader = null;

		try {
			// The bean processor read from annotation setted on Person.
			beanProcessor = rowBean.getBeanProcessor();

			// you could retreive CSVSettings from RowBean annotation in the aim
			// of customizing : CSVSettings settings =
			// rowBean.getReadingCSVSettings();
			// Or build it :
			CSVSettings settings = new CSVSettings().setCharsetName("UTF-8").setDelimiter('\'').setSeparator(',')
					.setWithHeaders(true);
			// The reader
			reader = new CSVReader(IN_FILE, settings);
			// The beanReader uses the bean processor and the reader.
			personReader = new BeanReader<Person>(beanProcessor, reader);

			System.out.println(String.format("New created Persons from file[%s] :", IN_FILE));
			while (personReader.hasNext()) {
				try {
					Person person = personReader.next();
					System.out.println(person.toString());
				} catch (ParseException ex) {
					System.out.println("Something went wrong on parsing");
					ex.printStackTrace();
				}
			}
		} catch (AnnotationProcessorException e) {
			e.printStackTrace();
		} catch (IOException e) {
			e.printStackTrace();
		} finally {// Some ReaderException may occur we haven't catched
			if (personReader != null) {
				personReader.close();
			}
		}

	}
}
