/*
 * Copyright 2013 Olivier Godineau
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package olg.csv.bean.sample.model;

import java.util.Date;

import olg.csv.bean.annotations.CSVProperty;
import olg.csv.bean.annotations.Column;
import olg.csv.bean.annotations.DateProperty;
import olg.csv.bean.annotations.Embedded;
import olg.csv.bean.annotations.Formatter;
import olg.csv.bean.annotations.ODSProperty;
import olg.csv.bean.annotations.Param;
import olg.csv.bean.annotations.Parser;
import olg.csv.bean.annotations.RowBean;

/**
 * A basic class to represent Persons
 * 
 * @author Olivier Godineau
 * 
 */
@RowBean(

CSVReadingParams = {

@Param(name = CSVProperty.HEADERS, value = "true"),

@Param(name = CSVProperty.CHARSETNAME, value = "UTF-8")

},

ODSWritingParams = {

@Param(name = ODSProperty.SHEETNAME, value = "Characters"), @Param(name = ODSProperty.BEGIN_AT_ROW, value = "5"),

@Param(name = ODSProperty.BEGIN_AT_COLUMN, value = "C")

},
CSVWritingParams = {

@Param(name = CSVProperty.HEADERS, value = "true"),

@Param(name = CSVProperty.CHARSETNAME, value = "UTF-8")

}

)
public class Person {

	@Column(name = "Name", value = "A")
	private String name = null;

	@Column(name = "Prenom", value = "B")
	private String firstName = null;

	@Column(name = "Company", value = "C")
	private String companyName = null;

	@Embedded("D")
	private Address address = null;

	@Column(name = "lastUpdate", value = "I")
	@Formatter(params = @Param(name = DateProperty.FORMAT, value = "dd-MM-yyyy HH:mm"))
	@Parser(params = @Param(name = DateProperty.FORMAT, value = "dd-MM-yyyy HH:mm"))
	private Date lastUpdate = null;

	public String getName() {

		return name;
	}

	public void setName(String name) {
		this.name = name;
	}

	public String getFirstName() {
		return firstName;
	}

	public void setFirstName(String firstName) {
		this.firstName = firstName;
	}

	public String getCompanyName() {
		return companyName;
	}

	public void setCompanyName(String companyName) {
		this.companyName = companyName;
	}

	public Address getAddress() {
		return address;
	}

	public void setAddress(Address address) {
		this.address = address;
	}

	public Date getLastUpdate() {
		return lastUpdate;
	}

	public void setLastUpdate(Date lastUpdate) {
		this.lastUpdate = lastUpdate;
	}

	public String toString() { // NOPMD by olivier on 07/02/12 19:28
		StringBuilder sBuf = new StringBuilder("name:"); // NOPMD by olivier on
															// 07/02/12 19:28
		sBuf.append((name != null ? name : "")).append(", firstname:").append((firstName != null ? firstName : ""))
				.append(", company:").append((companyName != null ? companyName : ""));
		sBuf.append(", address:").append((address != null ? address.toString() : "")).append(", last update:")
				.append((lastUpdate != null ? lastUpdate : ""));
		return sBuf.toString();

	}
}
