/*
 * Copyright 2013 Olivier Godineau
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package olg.csv.bean.annotations;

import java.lang.annotation.Documented;
import java.lang.annotation.ElementType;
import java.lang.annotation.Inherited;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * This annotation must be placed on a concrete class declaration to enable row
 * bean process. This annotation has no effect if placed on an interface
 * declaration.
 * 
 * @author Olivier Godineau
 * 
 */
@Documented
@Retention(RetentionPolicy.RUNTIME)
@Target(value = ElementType.TYPE)
@Inherited
public @interface RowBean {
	/**
	 * Allows to specify ODSSettings for reading. This settings will be used by
	 * {@link olg.csv.bean.RowBean} to instanciate an ODSReader.
	 * 
	 * @See {@link ODSProperty} to use the correct param name.
	 * @See by default, ODSSettings are the same as
	 *      {@link olg.csv.base.ods.ODSSettings#ODSSettings()}
	 * 
	 */
	Param[] ODSReadingParams() default {};
	/**
	 * Allows to specify CSVSettings for reading. This settings will be used by
	 * {@link olg.csv.bean.RowBean} to instanciate a CSVReader.
	 * 
	 * @See {@link CSVProperty} to use the correct param name.
	 * @See by default, CSVSettings are the same as
	 *      {@link olg.csv.base.csv.CSVSettings#CSVSettings()}
	 */
	Param[] CSVReadingParams() default {};
	/**
	 * Allows to specify ODSSettings for writing. This settings will be used by
	 * {@link olg.csv.bean.RowBean} to instanciate an ODSWriter.
	 * 
	 * @See {@link ODSProperty} to use the correct param name.
	 * @See by default, ODSSettings are the same as
	 *      {@link olg.csv.base.ods.ODSSettings#ODSSettings()}
	 */
	Param[] ODSWritingParams() default {};
	/**
	 * Allows to specify CSVSettings for writing. This settings will be used by
	 * {@link olg.csv.bean.RowBean} to instanciate a CSVWriter.
	 * 
	 * @See {@link CSVProperty} to use the correct param name.
	 * @See by default, CSVSettings are the same as
	 *      {@link olg.csv.base.csv.CSVSettings#CSVSettings()}
	 */
	Param[] CSVWritingParams() default {};

}
