/*
 * Copyright 2013 Olivier Godineau
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package olg.csv.bean.annotation.processor;

import java.lang.reflect.Field;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Map.Entry;

import olg.csv.bean.IPropertyProcessor;
import olg.csv.bean.annotation.test.model.TestColumnProcessorBean;
import olg.csv.bean.annotation.test.model.TestColumnProcessorParentBean;
import olg.csv.bean.annotations.processor.ColumnProcessor;
import olg.csv.bean.impl.CellProcessor;
import olg.csv.bean.impl.PropertyFormatter;

import org.junit.Assert;
import org.junit.Test;

public final class ColumnProcessorTest {
	// TODO tester les default value.

	@Test
	public void getWritingProcessorTest() throws NoSuchFieldException {
		Map<Integer, List<CellProcessor<TestColumnProcessorBean>>> map = new HashMap<Integer, List<CellProcessor<TestColumnProcessorBean>>>();
		Entry<Integer, List<CellProcessor<TestColumnProcessorBean>>> entry = null;
		List<CellProcessor<TestColumnProcessorBean>> list = null;
		CellProcessor<TestColumnProcessorBean> cellProcessor = null;
		PropertyFormatter formatter = null;
		boolean OK;
		ColumnProcessor<TestColumnProcessorBean> columnProcessor = new ColumnProcessor<TestColumnProcessorBean>(
				TestColumnProcessorBean.class);

		// FIRST CASE
		Field field = TestColumnProcessorBean.class.getDeclaredField("bean");

		OK = columnProcessor.getWritingProcessor(field, map);
		Assert.assertTrue("FIRST CASE - Writing process should be OK", OK);
		Assert.assertEquals("A column annotation is setted on the field", 1, map.size());

		entry = map.entrySet().iterator().next();
		Assert.assertEquals("Cell processor must be mapped on its value ", Integer.valueOf(2), entry.getKey());

		list = entry.getValue();
		Assert.assertEquals("a cellProcessor must be built from the annoted field", 1, list.size());

		cellProcessor = list.iterator().next();
		Assert.assertEquals("name column parameter must be read", "Bean", cellProcessor.getName());
		Assert.assertEquals("value column parameter must be read", 2, cellProcessor.getRang());

		formatter = cellProcessor.getPropertyFormatter();
		Assert.assertNotNull("A formatter must be setted into the cell Processor", formatter);

		// SECOND CASE : abstract class field
		field = TestColumnProcessorBean.class.getDeclaredField("iBeanOK");
		map = new HashMap<Integer, List<CellProcessor<TestColumnProcessorBean>>>();

		OK = columnProcessor.getWritingProcessor(field, map);
		Assert.assertTrue("2ND CASE - Writing process should be OK", OK);
		Assert.assertEquals("A column annotation is setted on the field", 1, map.size());

		entry = map.entrySet().iterator().next();
		Assert.assertEquals("Cell processor must be mapped on its value ", Integer.valueOf(40), entry.getKey());

		list = entry.getValue();
		Assert.assertEquals("a cellProcessor must be built from the annoted field", 1, list.size());

		cellProcessor = list.iterator().next();

		Assert.assertEquals("value column parameter must be read", 40, cellProcessor.getRang());

		formatter = cellProcessor.getPropertyFormatter();
		Assert.assertNotNull("A formatter must be setted into the cell Processor", formatter);

		// THIRD CASE : inherited field
		field = TestColumnProcessorParentBean.class.getDeclaredField("beanParent");
		map = new HashMap<Integer, List<CellProcessor<TestColumnProcessorBean>>>();

		OK = columnProcessor.getWritingProcessor(field, map);
		Assert.assertTrue("3RD CASE - Writing process should be OK", OK);
		Assert.assertEquals("A column annotation is setted on the field", 1, map.size());

		entry = map.entrySet().iterator().next();
		Assert.assertEquals("Cell processor must be mapped on its value ", Integer.valueOf(10), entry.getKey());

		list = entry.getValue();
		Assert.assertEquals("a cellProcessor must be built from the annoted field", 1, list.size());

		cellProcessor = list.iterator().next();
		Assert.assertEquals("name column parameter must be read", "Bean Parent", cellProcessor.getName());
		Assert.assertEquals("value column parameter must be read", 10, cellProcessor.getRang());

		formatter = cellProcessor.getPropertyFormatter();
		Assert.assertNotNull("A formatter must be setted into the cell Processor", formatter);

		// 4TH CASE : multiple field on same column

		Field fieldA = TestColumnProcessorBean.class.getDeclaredField("beanA");
		Field fieldB = TestColumnProcessorBean.class.getDeclaredField("beanB");
		map = new HashMap<Integer, List<CellProcessor<TestColumnProcessorBean>>>();

		OK = columnProcessor.getWritingProcessor(fieldA, map);
		Assert.assertTrue("4TH CASE - Writing process should be OK", OK);
		columnProcessor.getWritingProcessor(fieldB, map);
		Assert.assertEquals("the both fields should be mapped on the same column", 1, map.size());

		entry = map.entrySet().iterator().next();
		Assert.assertEquals("the both fields should be mapped on their column number", Integer.valueOf(0),
				entry.getKey());

		list = entry.getValue();
		Assert.assertEquals("the both fields should be mapped", 2, list.size());

	}

	@Test
	public void getWritingProcessorKOTest() throws NoSuchFieldException {
		Map<Integer, List<CellProcessor<TestColumnProcessorBean>>> map = new HashMap<Integer, List<CellProcessor<TestColumnProcessorBean>>>();
		ColumnProcessor<TestColumnProcessorBean> columnProcessor = new ColumnProcessor<TestColumnProcessorBean>(
				TestColumnProcessorBean.class);
		boolean OK;

		// no column annotation on field
		Field field = TestColumnProcessorBean.class.getDeclaredField("bean3");

		OK = columnProcessor.getWritingProcessor(field, map);
		Assert.assertTrue("No Column annotation : ColumnProcessor should be OK", OK);
		Assert.assertTrue("No Column annotation : no processor should be mapped", map.isEmpty());

		// no getter field case
		field = TestColumnProcessorBean.class.getDeclaredField("bean2");
		map = new HashMap<Integer, List<CellProcessor<TestColumnProcessorBean>>>();

		OK = columnProcessor.getWritingProcessor(field, map);
		Assert.assertFalse("no getter on field : ColumnProcessor should be KO", OK);

		// num cell format error case

		field = TestColumnProcessorBean.class.getDeclaredField("bean4");
		map = new HashMap<Integer, List<CellProcessor<TestColumnProcessorBean>>>();

		OK = columnProcessor.getWritingProcessor(field, map);
		Assert.assertFalse("Column value format error : ColumnProcessor should be KO", OK);

		// field concrete class not concret
		field = TestColumnProcessorBean.class.getDeclaredField("iBeanKO");
		map = new HashMap<Integer, List<CellProcessor<TestColumnProcessorBean>>>();

		OK = columnProcessor.getWritingProcessor(field, map);

		Assert.assertFalse("field class abstract : ColumnProcessor should be KO", OK);

	}
	@Test
	public void getReadingProcessorTest() throws NoSuchFieldException {
		ColumnProcessor<TestColumnProcessorBean> columnProcessor = new ColumnProcessor<TestColumnProcessorBean>(
				TestColumnProcessorBean.class);
		Map<Integer, Integer> map = new HashMap<Integer, Integer>();
		List<IPropertyProcessor<TestColumnProcessorBean>> fieldProcessors = new ArrayList<IPropertyProcessor<TestColumnProcessorBean>>();
		boolean OK;
		// FIRST CASE
		Field field = TestColumnProcessorBean.class.getDeclaredField("bean");

		OK = columnProcessor.getReadingProcessor(0, field, fieldProcessors, map);
		Assert.assertTrue("FIRST CASE - Writing process should be OK", OK);
		Assert.assertEquals(1, map.size());

		Entry<Integer, Integer> entry = map.entrySet().iterator().next();
		Assert.assertEquals(Integer.valueOf(2), entry.getKey());
		Assert.assertEquals(Integer.valueOf(1), entry.getValue());

		Assert.assertEquals(1, fieldProcessors.size());
		Assert.assertNotNull(fieldProcessors.iterator().next());

		// SECOND CASE : abstract class field
		field = TestColumnProcessorBean.class.getDeclaredField("iBeanOK");
		map.clear();
		fieldProcessors.clear();

		OK = columnProcessor.getReadingProcessor(0, field, fieldProcessors, map);
		Assert.assertTrue("2ND CASE - Writing process should be OK", OK);
		Assert.assertEquals(1, map.size());

		entry = map.entrySet().iterator().next();
		Assert.assertEquals(Integer.valueOf(40), entry.getKey());
		Assert.assertEquals(Integer.valueOf(1), entry.getValue());
		Assert.assertEquals(1, fieldProcessors.size());
		Assert.assertNotNull(fieldProcessors.iterator().next());

		// THIRD CASE : inherited field
		field = TestColumnProcessorParentBean.class.getDeclaredField("beanParent");
		map.clear();
		fieldProcessors.clear();

		OK = columnProcessor.getReadingProcessor(0, field, fieldProcessors, map);
		Assert.assertTrue("3RD CASE - Writing process should be OK", OK);
		Assert.assertEquals(1, map.size());

		entry = map.entrySet().iterator().next();
		Assert.assertEquals(Integer.valueOf(10), entry.getKey());
		Assert.assertEquals(Integer.valueOf(1), entry.getValue());
		Assert.assertEquals(1, fieldProcessors.size());
		Assert.assertNotNull(fieldProcessors.iterator().next());

		// 4TH CASE : multiple field on same column

		Field fieldA = TestColumnProcessorBean.class.getDeclaredField("beanA");
		Field fieldB = TestColumnProcessorBean.class.getDeclaredField("beanB");
		map.clear();
		fieldProcessors.clear();

		OK = columnProcessor.getReadingProcessor(0, fieldA, fieldProcessors, map);
		Assert.assertTrue("4TH CASE - Writing process should be OK", OK);
		OK = columnProcessor.getReadingProcessor(0, fieldB, fieldProcessors, map);
		Assert.assertTrue("4TH CASE - Writing process should be OK", OK);
		Assert.assertEquals(1, map.size());

		entry = map.entrySet().iterator().next();
		Assert.assertEquals(Integer.valueOf(0), entry.getKey());
		Assert.assertEquals(Integer.valueOf(2), entry.getValue());

		Assert.assertEquals(2, fieldProcessors.size());

	}
	@Test
	public void getReadingProcessorKOTest() throws NoSuchFieldException {
		ColumnProcessor<TestColumnProcessorBean> columnProcessor = new ColumnProcessor<TestColumnProcessorBean>(
				TestColumnProcessorBean.class);
		Map<Integer, Integer> map = new HashMap<Integer, Integer>();
		List<IPropertyProcessor<TestColumnProcessorBean>> fieldProcessors = new ArrayList<IPropertyProcessor<TestColumnProcessorBean>>();
		boolean KO;
		// No Column case
		Field field = TestColumnProcessorBean.class.getDeclaredField("bean3");

		KO = columnProcessor.getReadingProcessor(0, field, fieldProcessors, map);
		Assert.assertTrue("No Column annotation : ColumnProcessor should be OK", KO);
		Assert.assertTrue("No Column annotation : no processor should be mapped", map.isEmpty());

		// No setter case
		field = TestColumnProcessorBean.class.getDeclaredField("bean2");
		map.clear();
		fieldProcessors.clear();

		KO = columnProcessor.getReadingProcessor(0, field, fieldProcessors, map);
		Assert.assertFalse("No setter on field: ColumnProcessor should be KO", KO);

		// No Parser case
		field = TestColumnProcessorBean.class.getDeclaredField("bean5");
		map.clear();
		fieldProcessors.clear();

		KO = columnProcessor.getReadingProcessor(0, field, fieldProcessors, map);
		Assert.assertFalse("No parser on field: ColumnProcessor should be KO", KO);

		// Num cell format error
		field = TestColumnProcessorBean.class.getDeclaredField("bean4");
		map.clear();
		fieldProcessors.clear();

		KO = columnProcessor.getReadingProcessor(0, field, fieldProcessors, map);
		Assert.assertFalse("Column value format error : ColumnProcessor should be KO", KO);

		// field concrete class not concret

		field = TestColumnProcessorBean.class.getDeclaredField("iBeanKO");
		map.clear();
		fieldProcessors.clear();

		columnProcessor.getReadingProcessor(0, field, fieldProcessors, map);
		Assert.assertFalse("field class abstract : ColumnProcessor should be KO", KO);

	}
}
