/*
 * Copyright 2012 Olivier Godineau
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package olg.csv.base;

/**
 * Abstract class for SpreadSheet document writer. Embeds some Sheet writer
 * characteristics. Not a great interest : Provides a settings validation on
 * instanciation.
 * 
 * @author Olivier Godineau
 * 
 */
public abstract class AbstractSheetWriter implements IWriter {

	/**
	 * the sheet name on which write.
	 */
	protected String sheetName;

	/**
	 * Index from which begin the writing.
	 */
	protected Integer beginAtRow = 1;
	/**
	 * Index from which begin the row writing.
	 */
	protected Integer beginAtColumn = 0;
	/**
	 * Indicate if an header row must be written.
	 */
	protected boolean withHeaders;

	/**
	 * 
	 * @param settings
	 *            the settings.
	 */
	protected AbstractSheetWriter(AbstractSheetSettings<? extends AbstractSheetSettings<?>> settings) {
		if (settings == null) {
			throw new IllegalArgumentException("SheetWriter Constructor settings argument must not be null");
		}
		if (settings.getSheetName() == null) {
			throw new IllegalArgumentException(
					"SheetWriter constructor settings argument : must have not null sheetName attribut");
		}

		this.sheetName = settings.getSheetName();
		if (settings.getBeginAtRow() != null) {
			this.beginAtRow = settings.getBeginAtRow();
			if (this.beginAtRow < 1) {
				throw new IllegalArgumentException("SheetWriter Constructor ettings argument :beginAtRow parameter ["
						+ beginAtRow
						+ "] must be a positive number or null (in this last case reading begins at the first row)");

			}
		}

		if (settings.getBeginAtColumn() != null) {
			this.beginAtColumn = Cell.fromSheetCellNumber(settings.getBeginAtColumn());
		}
		this.withHeaders = settings.isWithHeaders();
	}

	/**
	 * Returns the sheet name.
	 * 
	 * @return the sheet name.
	 */
	public String getSheetName() {
		return sheetName;
	}

	/**
	 * Indicates if a header row must be written.
	 * 
	 * @return if a header row must be written
	 */
	public boolean isWithHeaders() {

		return withHeaders;
	}

}
