/*
 * Copyright 2012 Olivier Godineau
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package olg.csv.bean;

import olg.csv.base.Row;
import olg.csv.bean.parser.ParseException;

/**
 * In reading process, set properties of a bean from a row.
 * 
 * @author Olivier Godineau
 * 
 * @param <B>
 *            bean the processor deals with.
 */
public interface IPropertyProcessor<B> {

	/**
	 * Returns the bean after this transformer sets its property from a row.
	 * 
	 * @param line
	 *            the row. list of strings which represents the property of the
	 *            bean
	 * @param bean
	 *            the bean this transformer set property (or properties).
	 * @return the given bean.If the given bean is <code>null</code> a new
	 *         instance is created and returned.
	 * @throws ParseException
	 *             if error occurs during parsing
	 */
	B transform(Row line, B bean) throws ParseException;

}