/*
 * Copyright 2012 Olivier Godineau
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package olg.csv.bean.filter.impl;

import olg.csv.bean.filter.AbstractStringFilter;

/**
 * Filter which decorate the given string.
 * 
 * @author Olivier Godineau
 * 
 */
public final class DecorateFilter extends AbstractStringFilter {
	/**
	 * The string to place before.
	 */
	private String before;
	/**
	 * The string to place after.
	 */
	private String after;

	/**
	 * @param before
	 *            this string will be added front of the given string. Can be
	 *            <code>null</code>
	 * @param after
	 *            this string will be added behind the given string. Can be
	 *            <code>null</code>
	 */
	public DecorateFilter(String after, String before) {
		super();

		this.after = after;

		this.before = before;
	}

	@Override
	protected String doFiltre(String value) {
		String retour = value;
		if (value != null && !"".equals(value)) {
			retour = (before == null ? "" : before) + value + (after == null ? "" : after);
		}
		return retour;
	}

	/**
	 * 
	 * @return The string to place before.
	 */
	public String getBefore() {
		return before;
	}

	/**
	 * 
	 * @param before
	 *            the string to place before.
	 */
	public void setBefore(String before) {
		this.before = before;
	}

	/**
	 * @return the string to place after.
	 */
	public String getAfter() {
		return after;
	}

	/**
	 * 
	 * @param after
	 *            the string to place after.
	 */
	public void setAfter(String after) {
		this.after = after;
	}

}