/*
 * Copyright 2012 Olivier Godineau
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package olg.csv.bean.getter.impl;

import java.util.List;

import olg.csv.base.Row;
import olg.csv.bean.getter.AbstractGetter;

/**
 * This getter builds a String from a row by assembly Strings which are
 * producted by a list of getters.
 * 
 */
public final class ConcateGetter extends AbstractGetter {

	/**
	 * Returns The list of Getters.
	 * 
	 * @return the getters.
	 */
	// NOPMD by olivier on 01/02/12 00:22
	public List<AbstractGetter> getGetters() {
		return getters;
	}

	/**
	 * Sets the Getters list.
	 * 
	 * @param getters
	 *            the getter list.
	 */
	public void setGetters(List<AbstractGetter> getters) {
		this.getters = getters;
	}

	/**
	 * The Getters which product the Strings to assemble.
	 */
	private List<AbstractGetter> getters;

	/**
	 * 
	 * @param getters
	 *            Getters List that product Strings. Must not be null or empty.
	 * @param defaultValue
	 *            the value to return when assembly products an empty or
	 *            {@link NullPointerException} String
	 */
	public ConcateGetter(List<AbstractGetter> getters, String defaultValue) {
		super();
		this.getters = getters;
		setDefaultValue(defaultValue);
	}

	@Override
	protected String doGet(Row line) {
		StringBuffer str = new StringBuffer();
		for (AbstractGetter getter : getters) {
			String value = getter.get(line);
			if (value != null) {
				str.append(value);
			}
		}
		return str.toString();
	}

}