/*
 * Copyright 2012 Olivier Godineau
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package olg.csv.bean.loader.getter.impl;

import java.util.ArrayList;
import java.util.List;

import javax.xml.xpath.XPathConstants;
import javax.xml.xpath.XPathExpressionException;

import olg.csv.bean.getter.AbstractGetter;
import olg.csv.bean.loader.LoadException;
import olg.csv.bean.loader.Util;
import olg.csv.bean.loader.getter.AbstractGetterLoader;

import org.w3c.dom.Element;
import org.w3c.dom.NodeList;

/**
 * The loader characteristic of the concate getter.
 * 
 * @see AbstractGetter#getConcate(List, String)
 */
public final class ConcateGetterLoader extends AbstractGetterLoader {

	/**
	 * Constructs a loader bound with the assemble node.
	 * 
	 * @param successor
	 *            the next getter loader in the loader chain.
	 */
	public ConcateGetterLoader(AbstractGetterLoader successor) {
		super("assemble", successor);

	}

	@Override
	protected AbstractGetter getConcreteGetter(Element node, String defaultValue) throws XPathExpressionException,
			LoadException {
		List<AbstractGetter> getters = new ArrayList<AbstractGetter>();
		NodeList liste = (NodeList) Util.evaluerDOM(node, "getter", XPathConstants.NODESET);
		for (int index = 0; index < liste.getLength(); index++) {
			getters.add(AbstractGetterLoader.getInstance().getGetter((Element) liste.item(index)));
		}
		return AbstractGetter.getConcate(getters, defaultValue);
	}

}