/*
 * Copyright 2012 Olivier Godineau
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package olg.csv.bean.loader.parser.impl;

import java.util.Locale;

import olg.csv.bean.loader.LoadException;
import olg.csv.bean.loader.Util;
import olg.csv.bean.loader.parser.AbstractParserLoader;
import olg.csv.bean.parser.AbstractParser;

import org.w3c.dom.Element;

/**
 * Characteristic loader of Date parser described in XML node. This node must to
 * be conformed to DateParserType as defined in our XML schema.
 * 
 * @see AbstractParser#getDateParser(String, Class, Locale)
 * @see AbstractParser
 * 
 */
public final class DateParserLoader extends AbstractParserLoader {
	/**
	 * Constructor.
	 * 
	 * @param successor
	 *            the next parser loader in the loader chain.
	 */
	public DateParserLoader(AbstractParserLoader successor) {
		super("date", successor);

	}

	@SuppressWarnings({"unchecked", "rawtypes"})
	@Override
	protected AbstractParser getConcreteParser(Class clazz, Element node) throws LoadException {
		String loc = node.getAttribute("locale");
		Locale locale = Util.getLocale(loc);

		if (!"".equals(loc) && locale == null) {
			throw new LoadException("Locale based on expression[" + loc + "] is not available ");
		}
		return AbstractParser.getDateParser(node.getAttribute("format"), clazz, locale);
	}

}
