/*
 * Copyright 2012 Olivier Godineau
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package olg.csv.bean.parser.impl;

import java.lang.reflect.Constructor;
import java.lang.reflect.InvocationTargetException;

import olg.csv.bean.parser.AbstractParser;
import olg.csv.bean.parser.ParseException;

/**
 * Parser Use a constructor with string argument to parse a string.
 * 
 * @param <T>
 *            the parser target type
 */
public final class ConstructorParser<T> extends AbstractParser<T> {

	/**
	 * The constructor to use.
	 */
	private Constructor<T> constructeur;

	@Override
	public T parse(String str) {
		try {
			return constructeur.newInstance(str);
		} catch (IllegalArgumentException e) {
			throw new ParseException("ConstructorParser[" + constructeur.getDeclaringClass().getName() + "] error ", e);
		} catch (InstantiationException e) {
			throw new ParseException("ConstructorParser[" + constructeur.getDeclaringClass().getName() + "] error ", e);
		} catch (IllegalAccessException e) {
			throw new ParseException("ConstructorParser[" + constructeur.getDeclaringClass().getName() + "] error ", e);
		} catch (InvocationTargetException e) {
			throw new ParseException("ConstructorParser[" + constructeur.getDeclaringClass().getName() // NOPMD
																										// by
																										// olivier
																										// on
																										// 28/01/12
																										// 15:03
					+ "] error: ", e.getTargetException());
		}
	}

	/**
	 * Returns the Constructor for the given class which have a single String
	 * argument.
	 * 
	 * @param clazz
	 *            the parser target class
	 * @throws NoSuchMethodException
	 *             if no such constructor exists
	 */
	public ConstructorParser(Class<T> clazz) throws NoSuchMethodException {
		super();
		this.constructeur = clazz.getConstructor(new Class[]{String.class});

	}

}