/*
 * Copyright 2012 Olivier Godineau
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package olg.csv.bean.parser.impl;

import olg.csv.bean.parser.AbstractParser;

/**
 * Parser Decorator use for substitute null and empty string value by a default
 * string to be parsed.
 * 
 * @param <T>
 */
public final class DecorateParser<T> extends AbstractParser<T> {

	/**
	 * the decorated parser.
	 */
	private final AbstractParser<T> parser;
	/**
	 * the default value.
	 */
	private final String defaut;

	@Override
	public T parse(String str) {
		String toApply = null;
		if (str == null || "".equals(str.trim())) {
			toApply = defaut;
		} else {
			toApply = str.trim();
		}

		return parser.parse(toApply);

	}
	/**
	 * constructs a decorateParser.
	 * 
	 * @param parser
	 *            the parser.
	 * @param defaut
	 *            the default value to parse.
	 */
	public DecorateParser(AbstractParser<T> parser, String defaut) {
		super();
		this.parser = parser;
		this.defaut = defaut;
	}

}