/*
 * Copyright 2012 Olivier Godineau
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package olg.csv.bean.parser.impl;

import olg.csv.bean.parser.AbstractParser;
import olg.csv.bean.parser.ParseException;

/**
 * Parser dedicated in parsing string into enum.
 * 
 * @param <E>
 */
public final class EnumParser<E extends Enum<E>> extends AbstractParser<E> {

	/**
	 * Enum class.
	 */
	private final Class<E> enumClass;

	/**
	 * {@inheritDoc} Throws a ParseException if the argument is not
	 * <code>null</code> and could not be evaluate as an enum constant.
	 */
	public E parse(String str) {
		E retour = null;
		if (str != null) {
			try {
				// that's no sense to compare str with enum
				// name without trim
				retour = Enum.valueOf(enumClass, str.trim());
			} catch (IllegalArgumentException ex) {
				throw new ParseException(ex);
			}
		}
		return retour;

	}

	/**
	 * constructs EnumParser to parse a specific enum class.
	 * 
	 * @param enumClass
	 *            the enum class
	 */
	public EnumParser(Class<E> enumClass) {

		super();
		this.enumClass = enumClass;
	}
}