/*
 * Copyright 2012 Olivier Godineau
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package olg.csv.bean.getter;

import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import olg.csv.base.Cell;
import olg.csv.base.Row;
import olg.csv.bean.filter.AbstractStringFilter;
import olg.csv.bean.getter.AbstractGetter;
import olg.csv.bean.getter.GetterException;


import junit.framework.TestCase;

/**
 * Test propre à la classe AbstractGetter et à ses classes concrètes.
 * @author olivier
 *
 */
public class AbstractGetterTestCase extends TestCase {
	private final static Logger LOGGER = LoggerFactory.getLogger(AbstractGetterTestCase.class);
	private static class TestFilter extends AbstractStringFilter {
		private final String test ;
		@Override
		protected String doFiltre(String value) {
			String retour = value;
			if (value != null){
				retour = test + value;
			}
			return retour;
		}
		 TestFilter(String test) {
			super();
			this.test = test;
		}

	}

	public void testDefaultGetter() {
		AbstractGetter getter = AbstractGetter.getDefault("1", "defaultValue");
		
		List<Cell> line = new ArrayList<Cell>();
		line.add(new Cell(0,"value1"));
		line.add(new Cell(1,"value2"));
		assertEquals("value2", getter.get(new Row(1,line, 2)));
		getter.setFilter(new TestFilter("TEST"));
		assertEquals("TESTvalue2", getter.get(new Row(1,line, 2)));
		getter.setFilter(null);
		line.set(1, new Cell(1, null));
		assertEquals("defaultValue", getter.get(new Row(1,line, 2)));
		assertEquals("defaultValue", getter.get(new Row(1,null, 2)));
		getter.setFilter(new TestFilter("TEST"));
		assertEquals("defaultValue", getter.get(new Row(1,line, 2)));

		getter = AbstractGetter.getDefault("3", "defaultValue");
		try {
			getter.get(new Row(1,line, 2));
			fail("GetterException expected");
		} catch (GetterException ex) {
			LOGGER.debug("Expected Getting error",ex);
		} catch (Exception ex) {
			fail("Exception GetterException attendu : " + ex);
		}
		getter.setFilter(new TestFilter("TEST"));
		try {
			getter.get(new Row(1,line, 2));
			fail("GetterException expected");
		} catch (GetterException ex) {
			LOGGER.debug("Expected Getting error",ex);

		} catch (Exception ex) {
			fail("Exception GetterException expected : " + ex);
		}

	
	}

	public void testConstantGetter() {
		AbstractGetter getter = AbstractGetter.getConstant("value");
	
		assertEquals("value", getter.get(new Row(1,null,2)));
		List<Cell> line = new ArrayList<Cell>();
		line.add(new Cell(0,"value1"));
		line.add(new Cell(1,"value2"));
		assertEquals("value", getter.get(new Row(1,line,2)));
		getter.setFilter(new TestFilter("TEST"));
		assertEquals("TESTvalue", getter.get(new Row(1,null, 2)));
		assertEquals("TESTvalue", getter.get(new Row(1,line, 2)));
	}

	public void testConcateGetter() {
		ArrayList<AbstractGetter> getters = new ArrayList<AbstractGetter>();
		AbstractGetter getter = AbstractGetter.getConstant("value1");
		getters.add(getter);
		getter = AbstractGetter.getConstant("value2");
		getters.add(getter);
			
		getter = AbstractGetter.getConcate(getters, "defaultValue");
		List<Cell> line = new ArrayList<Cell>();
		line.add(new Cell(0,"value1"));
		line.add(new Cell(1,"value2"));
	
		assertEquals("value1"+"value2", getter.get(new Row(1,null, 2)));
		assertEquals("value1"+"value2", getter.get(new Row(1,line, 2)));
		getter.setFilter(new TestFilter("TEST"));
		assertEquals("TEST"+"value1"+"value2", getter.get(new Row(1,null, 2)));
		assertEquals("TEST"+"value1"+"value2", getter.get(new Row(1,line, 2)));
		
	}
}
