/*
 * Copyright 2012 Olivier Godineau
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package olg.csv.bean.loader;

import java.io.IOException;

import javax.xml.parsers.ParserConfigurationException;
import javax.xml.xpath.XPathConstants;
import javax.xml.xpath.XPathExpressionException;

import junit.framework.TestCase;
import olg.csv.bean.TestUtil;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.xml.sax.SAXException;

/**
 * CustomLoader class TestCase
 * 
 * @author Olivier Godineau
 * 
 */
public class CustomLoaderTestCase extends TestCase {
	private final static Logger LOGGER = LoggerFactory.getLogger(CustomLoaderTestCase.class);
	private final String xmlContent = "<custom class=\"olg.csv.bean.loader.CustomLoaderTestCase$CustomForTest\">\n"
			+ "	<property name=\"str\">\n" + "		<value>pour un test</value>\n" + "	</property><property name=\"f\">\n"
			+ "		<value>127.075</value>\n" + "	</property>\n" + "</custom>";

	/**
	 * Bean class for test
	 * 
	 * @author Olivier Godineau
	 * 
	 */
	public static class CustomForTest {
		private String str = null;
		private float theFloat;
		public float getF() {
			return theFloat;
		}
		public void setF(float aFloat) {
			this.theFloat = aFloat;
		}

		public String getStr() {
			return str;
		}
		public void setStr(String str) {
			this.str = str;
		}

	}

	/**
	 * Loading test of a custom class.
	 */
	public void testCustom() {
		Document doc = null;
		Element element = null;
		try {
			doc = TestUtil.openDocument(xmlContent);
			element = (Element) Util.evaluerDOM(doc, "/custom", XPathConstants.NODE);

		} catch (ParserConfigurationException e1) {
			LOGGER.debug("Error on XML Parser configuration", e1);
			fail(e1.toString());

		} catch (SAXException e1) {
			LOGGER.debug("Error on XML Parsing", e1);
			fail(e1.toString());

		} catch (IOException e1) {
			LOGGER.debug("Error on XML Parsing", e1);
			fail(e1.toString());

		} catch (XPathExpressionException e) {
			LOGGER.debug("Error on XML Parsing", e);
			fail(e.toString());

		}

		try {
			Object object = CustomLoader.getBean(element);
			assertTrue("XML element describe a CustomForTest instance",
					object instanceof olg.csv.bean.loader.CustomLoaderTestCase.CustomForTest);
			CustomForTest custom = (CustomForTest) object;
			assertEquals("Setting CustomForTest property failed", "pour un test", custom.getStr());
			assertEquals("Setting CustomForTest property failed", 127.075f, custom.getF());
		} catch (XPathExpressionException e) {
			LOGGER.debug("Error on loading", e);
			fail(e.toString());

		} catch (LoadException e) {
			LOGGER.debug("Error on loading", e);
			fail(e.toString());

		}

	}
}
