/*
 * Copyright 2012 Olivier Godineau
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package olg.csv.bean.parser;

import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.Locale;

import junit.framework.TestCase;


/**
 * AbstractParser class TestCase
 * @author Olivier Godineau
 *
 */
public class AbstractParserTestCase extends TestCase {


	public static class DateDefault extends Date {

		/**
		 * 
		 */
		private static final long serialVersionUID = -1955172361084099364L;

		public DateDefault() {
			super();

		}

	}

	public static class DateLongConstructor extends Date {

		/**
		 * 
		 */
		private static final long serialVersionUID = -5003251236155341833L;

		public DateLongConstructor(long date) {
			super(date);

		}

	}

	public static class StringConstructor {
		private String str;

		public StringConstructor(String str) {
			super();
			this.str = str;
		}

	}
	public static enum MyEnum{enum1, enum2}

	/**
	 * Date parsing test 
	 */
	public void testDateParser() {
		String pattern = "dd/MM/yyyy";
		String dateString = "24/03/2009";
		

		// Avec la classe java.util.Date par défaut
		AbstractParser<Date> parser = AbstractParser.getDateParser(pattern, null,null);
		assertNotNull("A new parser instance must be create",parser);
		try {
			Date date =  parser.parse(dateString);
			assertNotNull("Date parsing must return not null date",date);
			assertEquals("Date parsing must return Date instance",Date.class, date.getClass());

		} catch (ParseException e) {

			fail(e.toString());
		}

		try {
			Date date = (Date) parser.parse("24/ta/lala");

			fail("ParseException expected  but  parsing passed :" + date);
		} catch (ParseException e) { // NOPMD by olivier on 10/01/12 00:00

		}

		// Test avec classe héritant de la classe Date
		parser = AbstractParser.getDateParser(pattern, DateDefault.class, null);
		assertNotNull("A new parser instance must be create",parser);
		try {
			Date date = (Date) parser.parse(dateString);
			DateFormat dateFormat = new SimpleDateFormat(pattern);
			assertNotNull("Date parsing must return not null date",date);
			assertEquals("Date parsing must return the expected instance type",DateDefault.class, date.getClass());
			try {
				assertEquals("Date parsing must return the expected date",dateFormat.parse(dateString).getTime(), date.getTime());
			} catch (java.text.ParseException e) {
				fail(e.toString());
			}
		
		} catch (ParseException e) {

			fail(e.toString());
		}

		// Test avec classe héritant de la classe Date
		parser = AbstractParser.getDateParser(pattern, DateLongConstructor.class,null);
		assertNotNull("A new parser instance must be create",parser);
		try {
			Date date = (Date) parser.parse(dateString);
			assertNotNull("Date parsing must return not null date",date);
			assertEquals("Date parsing must return the expected instance type",DateLongConstructor.class, date.getClass());
			DateFormat dateFormat = new SimpleDateFormat(pattern);
			try {
				assertEquals("Date parsing must return the expected date",dateFormat.parse(dateString).getTime(), date.getTime());
			} catch (java.text.ParseException e) {
				fail(e.toString());
			}
			
		} catch (ParseException e) {

			fail(e.toString());
		}
		
		
		dateString = "mar. mars 2009";
		pattern = "EEE MMMM yyyy";
		try {
			DateFormat dateFormat = new SimpleDateFormat(pattern, Locale.FRENCH);
			Date date = dateFormat.parse(dateString);	
			parser  = AbstractParser.getDateParser(pattern, DateLongConstructor.class,new Locale("fr"));
	
			try {
				assertEquals("Date parsing must return the expected date",dateFormat.parse(dateString).getTime(), date.getTime());
			} catch (java.text.ParseException e) {
				fail(e.toString());
			}
			
		} catch (java.text.ParseException e) {
			fail(e.toString());
		}
		dateString = "Tue March 2009";
		try {
			DateFormat dateFormat = new SimpleDateFormat(pattern, Locale.ENGLISH);
			Date date = dateFormat.parse(dateString);	

			parser  = AbstractParser.getDateParser(pattern, DateLongConstructor.class,new Locale("en"));
	
			try {
				assertEquals("Date parsing must return the expected date",dateFormat.parse(dateString).getTime(), date.getTime());
			} catch (java.text.ParseException e) {
				fail(e.toString());
			}
			
		} catch (java.text.ParseException e) {
			fail(e.toString());
		}


	}

	/**
	 * ConstructorParser class test
	 */
	public void testConstructorParser() {
		String expectedValue ="test";
		AbstractParser<?> parser = AbstractParser.getConstructorParser(StringConstructor.class);
		assertNotNull("A new parser instance must be create",parser);
		try {
			Object object = parser.parse(expectedValue);
			assertNotNull("ConstructorParser parsing must return not null Object",object);
			assertEquals("ConstructorParser parsing must return the expected instance type ",StringConstructor.class, object.getClass());
			assertEquals("ConstructorParser parsing must return the expected value",expectedValue, ((StringConstructor) object).str);
		} catch (ParseException e) {
			fail(e.toString());
		}

	}
	
	/**
	 * EnumParser class test.
	 */
	public void testEnumParser(){
		AbstractParser<MyEnum> parser = AbstractParser.getEnumParser(MyEnum.class);
		assertEquals("Enum parser must parse an enum value", MyEnum.enum1, parser.parse(" enum1 "));
		assertEquals("Enum parser must parse an enum value", MyEnum.enum2, parser.parse(" enum2 "));
		try{
		assertEquals("", MyEnum.enum2, parser.parse(" enum3"));
		fail("ParseException must be thrown on illegal parse evaluation");
		}catch(Exception ex){
			assertEquals("ParseException must be the Exception thrown on parse error","ParseException",ex.getClass().getSimpleName());
		}
	}
	
	
	/**
	 * CharacterParser class test. 
	 */
	public void testCharacterParser(){
		AbstractParser<Character> parser = AbstractParser.getCharacterParser();
		assertEquals("Character parser must parse single char string", Character.valueOf('A'),parser.parse("A"));
		
		try{
			parser.parse("tralala");
			fail("ParseException must be thrown on illegal parse evaluation");
			}catch(Exception ex){
				assertEquals("ParseException must be the Exception thrown on parse error","ParseException",ex.getClass().getSimpleName());
			}
	}
	
	
	
	
	
	
	
}
